You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ofbiz.apache.org by ad...@apache.org on 2009/06/18 17:17:23 UTC

svn commit: r786117 - /ofbiz/trunk/framework/base/src/org/ofbiz/base/util/UtilXml.java

Author: adrianc
Date: Thu Jun 18 15:17:22 2009
New Revision: 786117

URL: http://svn.apache.org/viewvc?rev=786117&view=rev
Log:
Minor change to UtilXml.java DOM 3 method signature. No functional change.

Modified:
    ofbiz/trunk/framework/base/src/org/ofbiz/base/util/UtilXml.java

Modified: ofbiz/trunk/framework/base/src/org/ofbiz/base/util/UtilXml.java
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/base/src/org/ofbiz/base/util/UtilXml.java?rev=786117&r1=786116&r2=786117&view=diff
==============================================================================
--- ofbiz/trunk/framework/base/src/org/ofbiz/base/util/UtilXml.java (original)
+++ ofbiz/trunk/framework/base/src/org/ofbiz/base/util/UtilXml.java Thu Jun 18 15:17:22 2009
@@ -120,9 +120,9 @@
         return writer;
     }
 
     /** Serializes a DOM Element to an <code>OutputStream</code> using DOM 3.
      * @param os The <code>OutputStream</code> instance to write to
      * @param element The DOM <code>Element</code> object to be serialized
      * @param encoding Optional character encoding
      * @param includeXmlDeclaration If set to <code>true</code>,
      * the xml declaration will be included in the output
@@ -135,11 +135,11 @@
      * @throws InstantiationException
      * @throws IllegalAccessException
      */
-    public static void writeXmlDocument(OutputStream os, Element element, String encoding, boolean includeXmlDeclaration, boolean enablePrettyPrint) throws ClassCastException, ClassNotFoundException, InstantiationException, IllegalAccessException {
+    public static void writeXmlDocument(OutputStream os, Node node, String encoding, boolean includeXmlDeclaration, boolean enablePrettyPrint) throws ClassCastException, ClassNotFoundException, InstantiationException, IllegalAccessException {
         DOMImplementationLS impl = getDomLsImplementation();
         LSOutput out = createLSOutput(impl, os, encoding);
         LSSerializer writer = createLSSerializer(impl, includeXmlDeclaration, enablePrettyPrint);
-        writer.write(element, out);
+        writer.write(node, out);
     }
 
     // ----- TrAX Methods ----------------- //
@@ -120,9 +120,9 @@
     }
 
-    /** Serializes a DOM Element to an <code>OutputStream</code> using DOM 3.
+    /** Serializes a DOM Node to an <code>OutputStream</code> using DOM 3.
      * @param os The <code>OutputStream</code> instance to write to
@@ -120,9 +120,9 @@
      * @param os The <code>OutputStream</code> instance to write to
-     * @param element The DOM <code>Element</code> object to be serialized
+     * @param node The DOM <code>Node</code> object to be serialized
      * @param encoding Optional character encoding
      * @param includeXmlDeclaration If set to <code>true</code>,